@@ -8,7 +8,7 @@ use Apache::Session::Browseable::Store::Postgres;
 use Apache::Session::Generate::SHA256;
 use Apache::Session::Serialize::JSON;
 
-our $VERSION = '1.2.5';
+our $VERSION = '1.2.7';
 our @ISA     = qw(Apache::Session);
 
 sub populate {
@@ -45,10 +45,6 @@ sub searchOnExpr {
 sub _query {
     my ( $class, $args, $query, @fields ) = @_;
     my %res = ();
-    my $index =
-      ref( $args->{Index} )
-      ? $args->{Index}
-      : [ split /\s+/, $args->{Index} ];
 
     my $dbh        = $class->_classDbh($args);
     my $table_name = $args->{TableName}
@@ -56,20 +52,32 @@ sub _query {
 
     my $sth;
     my $fields =
-      join( ',', 'id', map { s/'//g; "a_session ->> '$_' AS $_" } @fields );
+      @fields
+      ? join( ',', 'id', map { s/'//g; "a_session ->> '$_' AS $_" } @fields )
+      : '*';
     $sth =
       $dbh->prepare("SELECT $fields from $table_name where $query->{query}");
     $sth->execute( @{ $query->{values} } );
 
     # In this case, PostgreSQL change field name in lowercase
     my $res = $sth->fetchall_hashref('id') or return {};
-    foreach (@fields) {
-        if ( $_ ne lc($_) ) {
-            foreach my $s ( keys %$res ) {
-                $res->{$s}->{$_} = delete $res->{$s}->{ lc $_ };
+    if (@fields) {
+        foreach (@fields) {
+            if ( $_ ne lc($_) ) {
+                foreach my $s ( keys %$res ) {
+                    $res->{$s}->{$_} = delete $res->{$s}->{ lc $_ };
+                }
             }
         }
     }
+    else {
+        my $self = eval "&${class}::populate();";
+        my $sub  = $self->{unserialize};
+        foreach my $s ( keys %$res ) {
+            my $tmp = &$sub( { serialized => $res->{$s}->{a_session} } );
+            $res->{$s} = $tmp;
+        }
+    }
     return $res;
 }
 
@@ -146,6 +154,8 @@ sub _classDbh {
       DBI->connect_cached( $datasource, $username, $password,
         { RaiseError => 1, AutoCommit => 1 } )
       || die $DBI::errstr;
+    $dbh->{pg_enable_utf8} = 1;
+    return $dbh;
 }
 
 1;
@@ -165,7 +175,7 @@ Create table:
       a_session jsonb,
   );
 
-Optionaly, add indexes on some fields. Example for Lemonldap::NG:
+Optionally, add indexes on some fields. Example for Lemonldap::NG:
 
   CREATE INDEX uid1 ON sessions USING BTREE ( (a_session ->> '_whatToTrace') );
   CREATE INDEX  s1  ON sessions ( (a_session ->> '_session_kind') );
